<?php
function get_msgs() {
	$msgs = array();
	foreach (glob(sapp_include_path() . 'locale.*.php') AS $locale_filepath)
		include_once($locale_filepath);
	return $msgs;
}

function msg($name, $locale = null)
{
	static $msgs;
	static $def_locale;

	if (!isset($msgs))
		$msgs = get_msgs();

	if (!isset($def_locale))
		$def_locale = $msgs['default'];

	if (null == $locale)
		$locale = sapp_get_locale();

	if (!isset($msgs[$locale]))
		$locale = $def_locale;

	if (isset($msgs[$locale][$name]))
		return $msgs[$locale][$name];
	elseif (isset($msgs[$def_locale][$name]))
		return $msgs[$def_locale][$name];
	else
		return $name;
}
function check_and_set_required($param_name, $additional_check = '') 
{
	$value = sapp_get_submit_value($param_name);

	// check that required parameter is set
	if (null === $value) {
		sapp_set_wrong($param_name);
		return false;
	}

	// parameter is specifyed - save it's value anyway
	sapp_set_param($param_name, $value);

	// check parameter's validity if validity-checking function is specifyed
	if ($additional_check !== '') {

		// check for validity-checking function existence
		if (!function_exists($additional_check)) {
			sapp_set_errormsg('Can\'t check parameter\'s "' . $param_name . '" validity: function "' . $additional_check . '" doesn\'t exist');
			sapp_set_wrong($param_name);
			return false;
		}

		// check parameter's validity
		if (!$additional_check($value)) {
			sapp_set_wrong($param_name, msg('invalid_value'));
			return false;
		}
	}

	// all checks done, parameter is specifyed and seems to be correct
	return true;
}

/**
 * Check if optional parameter is set. $additional check may specify validity-checking
 * function name.
 * If parameter is set and valid - register it and return true.
 * If parameter is set but not valid - mark it as erroneous and return false.
 * If parameter is not set - unregister it and return true.
 *
 * @param $param_name string
 * @param $additional_check string
 * @return boolean
 */
function check_and_set_optional($param_name, $additional_check = '') 
{
	$value = sapp_get_submit_value($param_name);

	// check if optional parameter is not set
	if (null === $value) {
		sapp_set_param($param_name, NULL);
		return true;
	}

	// parameter is specifyed - save it's value anyway
	sapp_set_param($param_name, $value);

	// check parameter's validity if validity-checking function is specifyed
	if ($additional_check !== '') {

		// check for validity-checking function existence
		if (!function_exists($additional_check)) {
			sapp_set_errormsg('Can\'t check parameter\'s "' . $param_name . '" validity: function "' . $additional_check . '" doesn\'t exist');
			sapp_set_wrong($param_name);
			return false;
		}

		// check parameter's validity
		if (!$additional_check($value)) {
			sapp_set_wrong($param_name);
			return false;
		}
	}

	// all checks done, parameter is specifyed and seems to be correct
	return true;
}


?>