<?
sapp_include_once('common.php');

/**
* Checks the validity of the current form.
*
* @return integer
*/

function form_handler()
{
	
	$valid_required = true;
	$valid_optional = true;
	$valid = true;

	/*******************************
	 *
	 *	Required parameters
	 *
	 *******************************/
	//check ssl
	$ssl = sapp_get_submit_value('ssl');
	switch ($ssl) {
		case 'true':
			sapp_set_ssl(true);
			break;

		default:
			sapp_set_ssl(false);
			break;
	}

        //check db name
        $dbname = sapp_get_submit_value('dbname');
        if (false === check_dbName($dbname)) {
                sapp_set_wrong('dbname', msg('invalid_value'));
                $valid = false;
        }

        sapp_set_param('dbname', $dbname);

        if (sapp_is_database_exists($dbname, 'mysql')) {
                sapp_set_wrong('dbname', msg('db__database_already_exists'));
                $valid = false;
        }

        //check db user
        $dbuser = sapp_get_submit_value('dbuser');
        if (false === check_dbUserName($dbuser)) {
                sapp_set_wrong('dbuser', msg('invalid_value'));
                $valid = false;
        }

        sapp_set_param('dbuser', $dbuser);

        //check db passwd
        $dbpasswd = sapp_get_submit_value('dbpasswd');
        $dbconfirm = sapp_get_submit_value('dbconfirm');
        if ('' == $dbpasswd) {
                if (false === sapp_get_param('dbpasswd')) {
                        sapp_set_wrong('dbpasswd', msg('password__empty'));
                        $valid = false;
                } else {
                        $dbpasswd = sapp_get_param('dbpasswd');
                }
        } elseif ($dbpasswd != $dbconfirm) {
                sapp_set_wrong('dbpasswd', msg('password__not_match'));
                sapp_set_wrong('dbconfirm', msg('password__not_match'));
                $valid = false;
        } else {
                sapp_set_param('dbpasswd', $dbpasswd);
        }

        if (sapp_is_database_user_exists($dbname, 'mysql', $dbuser, $dbpasswd)) {
                sapp_set_wrong('dbuser', msg('db__database_user_already_exists'));
                $valid = false;
        }

        if (false === $valid) {
                sapp_set_warning(msg('invalid_values'));
                return 1;
        }

        if (false === sapp_create_database($dbname, 'mysql')) {
                sapp_set_wrong('dbname', msg('db__unable_to_create'));
                return 1;
        }

        if (false === sapp_create_database_user($dbname, 'mysql', $dbuser, $dbpasswd)) {
                sapp_set_wrong('dbuser', msg('db__unable_to_create'));
                return 1;
        }



	// check install_prefix separately, as it requires special validity check
	$install_prefix = sapp_get_submit_value('install_prefix');
    	if (in_array($install_prefix, array(".", "/", "./")))
	{
		$ret = (function_exists('sapp_check_install_prefix'))? sapp_check_install_prefix(SITEAPP_PREFIX_ROOT) : false;
		if (false === $ret || false === in_array($ret, array(SITEAPP_DIR_NOT_EXISTS, SITEAPP_DIR_USED_BY_UNKNOWN)))
		{
			sapp_set_wrong('install_prefix', msg('install_prefix__invalid_name'));
			$valid = false;
		}
	}

    switch (sapp_set_install_prefix($install_prefix)) {

        case SITEAPP_DIR_NOT_EXISTS:
            break;

        case SITEAPP_DIR_USED_BY_UNKNOWN:
            sapp_set_wrong('install_prefix', msg('installation_directory_already_exists'));
            $valid = false;
            break;

        case SITEAPP_DIR_INVALID_NAME:
            sapp_set_wrong('install_prefix', msg('installation_directory_name_isn_t_valid'));
            $valid = false;
            break;

        case SITEAPP_DIR_USED_BY_SITEAPP:
            sapp_set_wrong('install_prefix', msg('installation_directory_is_used_by_other_site_application'));
            $valid = false;
            break;
    }

	$valid_required &= check_and_set_required('admin_login', 'check_sys_login');
	$valid_required &= check_and_set_required('admin_email', 'check_email');
	//check admin password
	$gal_admin_passwd = sapp_get_submit_value('admin_passwd');
	$gal_admin_confirm = sapp_get_submit_value('admin_confirm');
	if ('' == $gal_admin_passwd) {
		if (false === sapp_get_param('admin_passwd')) {
			sapp_set_wrong('admin_passwd', msg('password__empty'));
			$valid_required = false;
		} else {
			$gal_admin_passwd = sapp_get_param('admin_passwd');
		}
	} elseif ($gal_admin_passwd != $gal_admin_confirm) {
		sapp_set_wrong('admin_passwd', msg('password__not_match'));
		sapp_set_wrong('admin_confirm', msg('password__not_match'));
		$valid_required = false;
	} elseif (false === check_sys_passwd(sapp_get_param('admin_login'), $gal_admin_passwd)) {
		sapp_set_wrong('admin_passwd', msg('invalid_value'));
		$valid_required = false;
	} else {
	    $valid_required &= check_and_set_required('admin_passwd');
	}

	$salt = '';
	for ($i = 0; $i < 4; $i++) {
		$char = mt_rand(48, 109);
		$char += ($char > 90) ? 13 : ($char > 57) ? 7 : 0;
		$salt .= chr($char);
	}
	$admin_hash = $salt . md5($salt . $gal_admin_passwd);
	sapp_set_param("admin_hash", $admin_hash);

	$rand_pass = '';
	for ($i=0; $i<8; $i++){
		$rand_pass .= mt_rand(48, 109);
	}
	sapp_set_param("setup_admin_pass", $rand_pass);

	if (false === $valid_required)
		sapp_set_warning('Not all required parameters are correctly specifyed');
			
	$valid_optional &= check_and_set_optional('gallery_name');
	$valid_optional &= check_and_set_optional('admin_fullname');
#	$valid_optional &= check_and_set_optional('locale');

	if (false === $valid_optional)
		sapp_set_warning('Optional parameters are wrong');
		
	if (false === $valid_optional || false === $valid_required)
		return 1;
		
	// set application URL
	sapp_set_param('application_url', sapp_get_param('install_prefix'));

	return 2;
}

?>
